@@ -93,7 +93,7 @@ class CLI(cl1.CLI):
 	def start(self):
 		
 		# check arguments.
-		self.arguments.check(exceptions=["--log-level", "--create-alias", "--version"], json=JSON)
+		self.arguments.check(json=JSON)
 
 		#
 		# BASICS
@@ -101,11 +101,11 @@ class CLI(cl1.CLI):
 
 		# help.
 		if self.arguments.present(['-h', '--help']):
-			self.docs(success=True, json=JSON)
+			self.docs(success=True, json=syst3m.defaults.options.json)
 
 		# version.
 		elif self.arguments.present(['--version']):
-			print(f"{ALIAS} version:",Files.load(f"{SOURCE_PATH}/.version").replace("\n",""))
+			self.stop(message=f"{ALIAS} version:"+Files.load(f"{SOURCE_PATH}/.version").replace("\n",""), json=syst3m.defaults.options.json)
 
 		# config.
 		elif self.arguments.present('--config'):
@@ -180,7 +180,7 @@ class CLI(cl1.CLI):
 				# set passphrase.
 				elif self.arguments.present('--delete'):
 					passphrase = self.get_passphrase(required=False)
-					if passphrase == None:
+					if passphrase in [False, None, "", "null", "None", "none"]:
 						if alias_info["smart_card"]:
 							if pin != verify_pin:
 								self.stop(error="Passphrases do not match.")
@@ -304,7 +304,7 @@ class CLI(cl1.CLI):
 			
 			# generate a key.
 			passphrase = self.get_passphrase(required=False)
-			if passphrase in ["", None, "null", "None", "none"]: passphrase = None
+			if passphrase in [False, None, "", "null", "None", "none"]: passphrase = None
 			response = ssht00ls.key.generate(
 				path=self.arguments.get("--path", chapter="keys", mode="--generate"), 
 				passphrase=passphrase, 
@@ -502,7 +502,7 @@ class CLI(cl1.CLI):
 		#
 	def get_passphrase(self, required=True):
 		passphrase = self.arguments.get("--passphrase", required=required)
-		if passphrase != None: return passphrase.replace("\\", "").replace("\ ", "")
+		if passphrase not in [False, None, "", "null", "None", "none"]: return passphrase.replace("\\", "").replace("\ ", "")
 		else: return passphrase
 # main.
 if __name__ == "__main__":
