@@ -25,17 +25,17 @@ class Aliases(object):
 	def check(self, alias):
 		try: CONFIG["aliases"][alias]
 		except KeyError:
-			return r3sponse.error_response(f"Alias {alias} does not exist.")
-		return r3sponse.success_response(f"Successfully checked alias {alias}.")
+			return r3sponse.error(f"Alias {alias} does not exist.")
+		return r3sponse.success(f"Successfully checked alias {alias}.")
 	def check_duplicate(self, alias):
 		try: CONFIG["aliases"][alias]
 		except KeyError:
-			return r3sponse.success_response(f"Alias {alias} does not exist.")
-		return r3sponse.error_response(f"Alias {alias} already exists.")
+			return r3sponse.success(f"Alias {alias} does not exist.")
+		return r3sponse.error(f"Alias {alias} already exists.")
 	def info(self, alias):
 		response = self.check(alias)
 		if not response["success"]: return response
-		return r3sponse.success_response(f"Successfully listed the info of alias {alias}.", {
+		return r3sponse.success(f"Successfully listed the info of alias {alias}.", {
 			"info":CONFIG["aliases"][alias],
 		})
 	def delete(self, alias):
@@ -43,7 +43,7 @@ class Aliases(object):
 		if not response["success"]: return response
 		del CONFIG["aliases"][alias]
 		CONFIG.save()
-		return r3sponse.success_response(f"Successfully deleted alias {alias}.")
+		return r3sponse.success(f"Successfully deleted alias {alias}.")
 	def edit(self, 
 		# the alias.
 		alias=None,
@@ -86,9 +86,9 @@ class Aliases(object):
 			CONFIG.dictionary = dictionary
 			CONFIG.save()
 		if c > 0:
-			return r3sponse.success_response(f"Successfully saved {c} edits for alias {alias}.")
+			return r3sponse.success(f"Successfully saved {c} edits for alias {alias}.")
 		else:
-			return r3sponse.error_response(f"No edits were specified.")
+			return r3sponse.error(f"No edits were specified.")
 	def create(self, 
 		# the alias.
 		alias=None,
@@ -174,9 +174,9 @@ class Aliases(object):
 		private_key = syst3m.env.fill(private_key)
 		public_key = syst3m.env.fill(public_key)
 		if not os.path.exists(private_key):
-			return r3sponse.error_response(f"Private key {private_key} does not exist.")
+			return r3sponse.error(f"Private key {private_key} does not exist.")
 		if not os.path.exists(public_key):
-			return r3sponse.error_response(f"Public key {public_key} does not exist.")
+			return r3sponse.error(f"Public key {public_key} does not exist.")
 
 		# info.
 		json_config, config = {}, ""
@@ -210,21 +210,27 @@ class Aliases(object):
 			json_config["smart_card"] = True
 			config += "\n    PKCS11Provider {}".format(smart_cards.path)
 
-		# save.
-		if save:
-			CONFIG["aliases"][alias] = json_config
+		# passphrase.
+		if passphrase not in [False, "", "none", None, "None"]:
 			if smart_card:
 				response = ENCRYPTION.encrypt(str(pin))
 				if not response["success"]: return response
-				CONFIG["aliases"][alias]["pin"] = response["encrypted"].decode()
+				json_config["pin"] = response["encrypted"].decode()
 			else:
 				response = ENCRYPTION.encrypt(str(passphrase))
 				if not response["success"]: return response
-				CONFIG["aliases"][alias]["passphrase"] = response["encrypted"].decode()
+				json_config["passphrase"] = response["encrypted"].decode()
+		else:
+			json_config["passphrase"] = ""
+			json_config["pin"] = ""
+
+		# save.
+		if save:
+			CONFIG["aliases"][alias] = json_config
 			CONFIG.save()
 
 		# response.
-		return r3sponse.success_response(f"Successfully created alias [{alias}].", {
+		return r3sponse.success(f"Successfully created alias [{alias}].", {
 			"json":json_config,
 			"str":config,
 		})
@@ -258,9 +264,9 @@ class Aliases(object):
 					checked["public_key"] = syst3m.env.fill(checked["public_key"])
 				if not cl1.argument_present("--non-interactive"):
 					passphrase = None
-					if checked["smart_card"] and checked["pin"] in [None, "", "none", "None"]:
+					if checked["smart_card"] and checked["pin"] in [False, None, "", "none", "None"]:
 						passphrase =  getpass.getpass(f"Enter the passphrase of key {checked['private_key']}:")
-					elif checked["passphrase"] in [None, "", "none", "None"]:
+					elif checked["passphrase"] in [False, None, "", "none", "None"]:
 						passphrase =  getpass.getpass(f"Enter the passphrase of key {checked['private_key']}:")
 					if checked["smart_card"]:
 						response = agent.check(public_key=checked["public_key"], raw=True)
@@ -275,7 +281,7 @@ class Aliases(object):
 							else:
 								response = agent.add(path=checked["private_key"], passphrase=passphrase)
 								if not response["success"]: return response
-					if passphrase != None:
+					if passphrase not in [False, None, "", "none", "None"]:
 						response = ENCRYPTION.encrypt(passphrase)
 						if not response.success: return response
 						if checked["smart_card"]:
@@ -288,7 +294,7 @@ class Aliases(object):
 				aliases += response["str"]
 				c += 1
 		Files.save(f"{HOME}/.ssht00ls/lib/aliases", aliases)
-		return r3sponse.success_response(f"Successfully synchronized {c} alias(es).")
+		return r3sponse.success(f"Successfully synchronized {c} alias(es).")
 
 # initialized objects.
 aliases = Aliases()
