@@ -12,8 +12,7 @@ except ImportError:
 	else: os.system(f"pip3 install cl1")
 	import cl1
 if cl1.arguments_present(["--update"]):
-	#os.system(f"curl https://raw.githubusercontent.com/vandenberghinc/{ALIAS}/master/{ALIAS}/requirements/installer.remote | bash ")
-	os.system(f'e="/tmp/import" && rm -fr $e && curl https://raw.githubusercontent.com/vandenberghinc/{ALIAS}/master/{ALIAS}/requirements/installer.remote -o $e && chmod +x $e && bash $e')
+	os.system(f"curl -s https://raw.githubusercontent.com/vandenberghinc/{ALIAS}/master/{ALIAS}/requirements/installer.remote | bash ")
 	sys.exit(0)
 
 # imports.
@@ -23,7 +22,7 @@ try:
 	import os, sys, requests, ast, json, pathlib, glob, platform, subprocess, pexpect, random, getpass, time
 
 	# inc imports.
-	from fil3s import Files, Formats, gfp
+	from fil3s import *
 	from r3sponse import r3sponse
 	import cl1, syst3m, encrypti0n, netw0rk
 
@@ -39,7 +38,7 @@ except ImportError as e:
 	import os, sys, requests, ast, json, pathlib, glob, platform, subprocess, pexpect, random, getpass, time
 
 	# inc imports.
-	from fil3s import Files, Formats
+	from fil3s import *
 	from r3sponse import r3sponse
 	import cl1, syst3m, encrypti0n, netw0rk
 
@@ -56,6 +55,9 @@ INTERACTIVE = not cl1.arguments_present(["--non-interactive"])
 CHECKS = not cl1.arguments_present(["--no-checks"])
 JSON = cl1.arguments_present(["-j", "--json"])
 
+# version.
+version = Files.load(f"{SOURCE_PATH}/.version")
+
 # universal variables.
 USER = OWNER = os.environ.get("USER")
 GROUP = "root"
@@ -208,7 +210,7 @@ if CHECKS:
 			response, new, passphrase = webserver.get(group="passphrases", id="master"), False, None
 			if response["success"]:
 				passphrase = response["data"]
-			if passphrase == None:
+			if passphrase in [False, None, "", "null", "None", "none"]:
 				if not INTERACTIVE:
 					r3sponse.log(error=response.error, json=JSON)
 					sys.exit(1)
@@ -231,7 +233,7 @@ if CHECKS:
 					sys.exit(1)
 
 		# encrypted database.
-		if passphrase != None:
+		if passphrase not in [False, None, "", "null", "None", "none"]:
 			ENCRYPTED_DATABASE = encrypti0n.aes.Database(path=f"{HOME}/.{ALIAS}/.cache.enc/", aes=ENCRYPTION)
 			response = ENCRYPTED_DATABASE.activate()
 			if not response["success"]: 
