@@ -37,7 +37,7 @@ def execute(
 	#try:
 	#	output = subprocess.check_output(["sh", path]).decode()
 	#except subprocess.CalledProcessError as e:
-	#	return r3sponse.error_response(f"Failed to execute command [{command}], (output: {e.output}), (error: {e}).")
+	#	return r3sponse.error(f"Failed to execute command [{command}], (output: {e.output}), (error: {e}).")
 
 	# version 3.
 	#response = syst3m.console.execute(
@@ -59,13 +59,13 @@ def execute(
 		if isinstance(error_, bytes): error_ = error_.decode()
 		if isinstance(output, bytes): output = error_.decode()
 		if loader != None: loader.stop(success=False)
-		return r3sponse.error_response(f"Failed to execute command ({command}), (error: {error_}), (output: {output}).")
+		return r3sponse.error(f"Failed to execute command ({command}), (error: {error_}), (output: {output}).")
 	error_, output = proc.stderr, proc.stdout
 	if isinstance(error_, bytes): error_ = error_.decode()
 	if isinstance(output, bytes): output = error_.decode()
 	if error_ != "":
 		if loader != None: loader.stop(success=False)
-		return r3sponse.error_response(f"Failed to execute command ({command}), (error: {error_}), (output: {output}).")
+		return r3sponse.error(f"Failed to execute command ({command}), (error: {error_}), (output: {output}).")
 	if len(output) > 0 and output[len(output)-1] == "\n": output = output[:-1]
 	Files.delete(path)
 
@@ -75,23 +75,23 @@ def execute(
 		if loader != None: loader.stop(success=False)
 		return response
 		#print(output)
-		#return r3sponse.error_response(error)
+		#return r3sponse.error(error)
 	else:
 		if serialize:
 			try: response = r3sponse.ResponseObject(json=output)
 			except Exception as e: 
 				if loader != None: loader.stop(success=False)
-				return r3sponse.error_response(f"Failed to serialize output: {output}")
+				return r3sponse.error(f"Failed to serialize output: {output}")
 			if loader != None: loader.stop()
 			return response
 		else:
 			if loader != None: loader.stop()
 			if get_output:
-				return r3sponse.success_response(message, {
+				return r3sponse.success(message, {
 					"output":output,
 				})
 			else:
-				return r3sponse.success_response(message)
+				return r3sponse.success(message)
 
 	#
 
@@ -110,18 +110,18 @@ def check_errors(output):
 				if len(e) > 0 and e[len(e)-1] in [" ", "."]: e = e[:-1]
 				elif len(e) > 0 and e[0] in [" "]: e = e[1:]
 				else: break
-			return r3sponse.error_response(e+".")
-	return r3sponse.success_response("The output contains no (default) errors.")
+			return r3sponse.error(e+".")
+	return r3sponse.success("The output contains no (default) errors.")
 def test_ssh(alias=None, accept_new_host_keys=True, checks=True):
 	accept_new_host_keys = Formats.Boolean(accept_new_host_keys).convert(true="printf 'yes' | ", false="")
 	output = syst3m.utils.__execute_script__(f"""{accept_new_host_keys}ssh {DEFAULT_SSH_OPTIONS} {alias} ' echo "Hello World" ' """)
 	response = check_errors(output)
 	if not response.success:
-		return r3sponse.error_response(f"Failed to connect with {alias}, error: {output}")
+		return r3sponse.error(f"Failed to connect with {alias}, error: {output}")
 	elif "Hello World" in output:
-		return r3sponse.success_response(f"Successfully connected with {alias}.")
+		return r3sponse.success(f"Successfully connected with {alias}.")
 	else:
-		return r3sponse.error_response(f"Failed to connect with {alias}, error: {output}")
+		return r3sponse.error(f"Failed to connect with {alias}, error: {output}")
 def test_ssh_path(alias=None, path=None, accept_new_host_keys=True, checks=True):
 	if checks:
 		response = test_ssh(alias=alias, accept_new_host_keys=accept_new_host_keys)
@@ -129,11 +129,11 @@ def test_ssh_path(alias=None, path=None, accept_new_host_keys=True, checks=True)
 	output = syst3m.utils.__execute_script__(f"""ssh {DEFAULT_SSH_OPTIONS} {alias} ' ls -ld {path} ' """)
 	response = check_errors(output)
 	if not response.success:
-		return r3sponse.error_response(f"Path {alias}:{path} does not exist.")
+		return r3sponse.error(f"Path {alias}:{path} does not exist.")
 	elif "No such file or directory" not in output:
-		return r3sponse.success_response(f"Path {alias}:{path} exists.")
+		return r3sponse.success(f"Path {alias}:{path} exists.")
 	else:
-		return r3sponse.error_response(f"Path {alias}:{path} does not exist.")
+		return r3sponse.error(f"Path {alias}:{path} does not exist.")
 def test_ssh_dir(alias=None, path=None, accept_new_host_keys=True, create=False, created=False, checks=True):
 	if checks:
 		response = test_ssh(alias=alias, accept_new_host_keys=accept_new_host_keys)
@@ -141,21 +141,21 @@ def test_ssh_dir(alias=None, path=None, accept_new_host_keys=True, create=False,
 	lpath = "\'"+path+"\'"
 	output = syst3m.utils.__execute_script__(f"""ssh {DEFAULT_SSH_OPTIONS} {alias} ''' python3 /usr/local/lib/ssht00ls/classes/utils/isdir.py {path}''' """)
 	if output.replace("\n","") == "directory":
-		return r3sponse.success_response(f"Path {alias}:{path} is a directory.", {
+		return r3sponse.success(f"Path {alias}:{path} is a directory.", {
 			"created":created,
 		})
 	elif output.replace("\n","") in ["directory", "does-not-exist"]:
 		if output.replace("\n","") in ["does-not-exist"]:
 			if create:
 				output = syst3m.utils.__execute_script__(f"""ssh {DEFAULT_SSH_OPTIONS} {alias} ''' mkdir -p {path}''' """)
-				if "permission denied" in output: return r3sponse.error_response(f"Unable to create remote directory [{alias}:{path}].")
+				if "permission denied" in output: return r3sponse.error(f"Unable to create remote directory [{alias}:{path}].")
 				return test_ssh_dir(alias=alias, path=path, checks=False, create=False, created=True)
 			else:
-				return r3sponse.error_response(f"Path {alias}:{path} does not exist.")
+				return r3sponse.error(f"Path {alias}:{path} does not exist.")
 		else:
-			return r3sponse.error_response(f"Path {alias}:{path} is not a directory.")
+			return r3sponse.error(f"Path {alias}:{path} is not a directory.")
 	else:
-		return r3sponse.error_response(f"Unable to check remote directory {alias}:{path}, output: {output}.")
+		return r3sponse.error(f"Unable to check remote directory {alias}:{path}, output: {output}.")
 def test_ssht00ls(alias=None, accept_new_host_keys=True, install=True):
 	for path in [f"/usr/local/lib/{ALIAS}"]:
 		response = test_ssh_path(alias=alias, accept_new_host_keys=accept_new_host_keys, path=path)
@@ -169,10 +169,10 @@ def test_ssht00ls(alias=None, accept_new_host_keys=True, install=True):
 					print(output)
 					return response
 				else:
-					return r3sponse.error_response(f"Remote {alias} does not have library ssht00ls installed.")
+					return r3sponse.error(f"Remote {alias} does not have library ssht00ls installed.")
 			else:
 				return response
-	return r3sponse.success_response(f"Remote {alias} has library ssht00ls installed.")
+	return r3sponse.success(f"Remote {alias} has library ssht00ls installed.")
 
 # check / start the ssh agent.
 def ssh_agent():
@@ -225,4 +225,4 @@ def kill_ssh(identifier=None, sudo=False, dont_kill=["grep", "ssht00ls"]):
 				else:
 					loader.stop(success=False)
 					r3sponse.log(f"Failed to stop process {pid}, error: {output}")
-	return r3sponse.success_response(f"Successfully killed {killed} process(es) that included identifier [{identifier}].")
+	return r3sponse.success(f"Successfully killed {killed} process(es) that included identifier [{identifier}].")
