@@ -51,12 +51,12 @@ class SSync(object):
 		if not response["success"]: return response
 		if mode in ["synchronize", "sync", "synch"]: mode = "sync"
 		if mode not in ["mount", "sync"]:
-			return r3sponse.error_response(f"Specified an invalid mode: [{mode}], options: [mount, sync].")
+			return r3sponse.error(f"Specified an invalid mode: [{mode}], options: [mount, sync].")
 		cache_path = gfp.absolute(path=gfp.clean(path.split(" (d)")[0], remove_last_slash=True))
 		if mode in ["mount"] and not forced and os.path.exists(path):
-			return r3sponse.error_response(f"Path [{path}] already exists.")
+			return r3sponse.error(f"Path [{path}] already exists.")
 		elif self.daemons.running(cache_path):
-			return r3sponse.error_response(f"Path [{path}] is already mounted.")
+			return r3sponse.error(f"Path [{path}] is already mounted.")
 		path = gfp.clean(path=path)
 		remote = gfp.clean(path=remote)
 
@@ -83,29 +83,29 @@ class SSync(object):
 				else:
 					return response
 			if not remote_exists and not local_exists:
-				return r3sponse.error_response(f"Both local and remote directories {path} & {alias}:{remote} do not exist.")
+				return r3sponse.error(f"Both local and remote directories {path} & {alias}:{remote} do not exist.")
 			if not local_exists:
 				os.system(f"mkdir -p {path}")
 				if not os.path.exists(path): 
-					return r3sponse.error_response(f"Failed to create directory {path}.")
+					return r3sponse.error(f"Failed to create directory {path}.")
 			if not remote_exists:
 				response = ssh.utils.test_ssh_dir(path=remote, alias=alias, create=True)
 				if not response["success"]: 
-					return r3sponse.error_response(f"Failed to create directory {alias}:{remote}, error: {response['error']}")
+					return r3sponse.error(f"Failed to create directory {alias}:{remote}, error: {response['error']}")
 
 		# start daemon.
 		cache.set(id=cache_path, group="daemons", data=f"*running* (timestamp={Formats.Date().seconds_timestamp})")
 		self.set_mounted_icon(path)
 		if not self.daemons.running(cache_path):
-			return r3sponse.error_response(f"Failed to set the {path} daemon status.")
+			return r3sponse.error(f"Failed to set the {path} daemon status.")
 		response =  self.daemon(alias=alias, path=path, remote=remote, start=True, mode=mode)
 		if not response.success: return response
 
 		# handler.
 		if mode == "sync":
-			return r3sponse.success_response(f"Successfully synchronized {alias}:{remote} to {path}.")
+			return r3sponse.success(f"Successfully synchronized {alias}:{remote} to {path}.")
 		else:
-			return r3sponse.success_response(f"Successfully mounted {alias}:{remote} to {path}.")
+			return r3sponse.success(f"Successfully mounted {alias}:{remote} to {path}.")
 
 		#
 	def unmount(self, 
@@ -129,26 +129,26 @@ class SSync(object):
 		cache_path = gfp.absolute(gfp.clean(path.split(" (d)")[0], remove_last_slash=True))
 		if not self.daemons.running(cache_path):
 			if not os.path.exists(path):
-				return r3sponse.error_response(f"Path [{path}] does not exist.")
+				return r3sponse.error(f"Path [{path}] does not exist.")
 			elif not os.path.isdir(path):
-				return r3sponse.error_response(f"Path [{path}] is not a directory.")
+				return r3sponse.error(f"Path [{path}] is not a directory.")
 			status = str(cache.get(id=cache_path, group="daemons"))
 			if not self.daemons.running(cache_path):
-				return r3sponse.error_response(f"Path [{path}] is not mounted (status: {status}).")
+				return r3sponse.error(f"Path [{path}] is not mounted (status: {status}).")
 
 		# wait for daemon stop.
 		response = self.daemons.stop(path=path)
 		if not success: return response
 
 		# handler.
-		return r3sponse.success_response(f"Successfully unmounted [{path}].")
+		return r3sponse.success(f"Successfully unmounted [{path}].")
 
 		#
 	def index(self, path=None, alias=None, log_level=0, checks=True, accept_new_host_keys=True):
 
 		# checks.
 		if path == None:
-			return r3sponse.error_response(f"Define parameter: path.")
+			return r3sponse.error(f"Define parameter: path.")
 		path = gfp.clean(path)
 
 		# remote.
@@ -187,13 +187,13 @@ class SSync(object):
 		else:
 			if checks:
 				if not os.path.exists(path):
-					return r3sponse.error_response(f"Path [{path}] does not exist.")
+					return r3sponse.error(f"Path [{path}] does not exist.")
 				elif not os.path.isdir(path):
-					return r3sponse.error_response(f"Path [{path}] is not a directory.")
+					return r3sponse.error(f"Path [{path}] is not a directory.")
 
 			# handler.
 			dict = self.utils.index(path)
-			return r3sponse.success_response(f"Successfully indexed {len(dict)} files from directory [{path}].", {
+			return r3sponse.success(f"Successfully indexed {len(dict)} files from directory [{path}].", {
 				"index":dict,
 			})
 
@@ -412,7 +412,7 @@ class SSync(object):
 			})
 		if mode in ["synchronize", "sync", "synch"]: mode = "sync"
 		if mode not in ["mount", "sync"]:
-			return r3sponse.error_response(f"Specified an invalid mode: [{mode}], options: [mount, sync].")
+			return r3sponse.error(f"Specified an invalid mode: [{mode}], options: [mount, sync].")
 		path = gfp.clean(path)
 		remote = gfp.clean(remote)
 		_daemon_ = daemons.Daemon({
@@ -427,7 +427,7 @@ class SSync(object):
 			"sleeptime":sleeptime,
 		})
 		if start: webserver.start_daemon(_daemon_, group="daemons", id=_daemon_.id)
-		return r3sponse.success_response("Successfully initialized the daemon", {
+		return r3sponse.success("Successfully initialized the daemon", {
 			"daemon":_daemon_,
 		})
 	
